@@ -52,11 +52,8 @@ KsGLWidget::KsGLWidget(QWidget *parent)
 {
 	setMouseTracking(true);
 
-	/*
-	 * Using the old Signal-Slot syntax because QWidget::update has
-	 * overloads.
-	 */
-	connect(&_model, SIGNAL(modelReset()), this, SLOT(update()));
+	connect(&_model,	&QAbstractTableModel::modelReset,
+		this,		qOverload<>(&KsGLWidget::update));
 }
 
 void KsGLWidget::_freeGraphs()
@@ -86,17 +83,17 @@ KsGLWidget::~KsGLWidget()
 /** Reimplemented function used to set up all required OpenGL resources. */
 void KsGLWidget::initializeGL()
 {
-	_dpr = QApplication::desktop()->devicePixelRatio();
+	_dpr = QApplication::primaryScreen()->devicePixelRatio();
 	ksplot_init_opengl(_dpr);
 
 	ksplot_init_font(&_font, 15, TT_FONT_FILE);
 
 	_labelSize = _getMaxLabelSize() + FONT_WIDTH * 2;
-	update();
+	updateGeom();
 }
 
 /**
- * Reimplemented function used to reprocess all graphs whene the widget has
+ * Reimplemented function used to reprocess all graphs when the widget has
  * been resized.
  */
 void KsGLWidget::resizeGL(int w, int h)
@@ -140,9 +137,10 @@ void KsGLWidget::paintGL()
 	/* Draw the time axis. */
 	_drawAxisX(size);
 
-	for (auto const &stream: _graphs)
-		for (auto const &g: stream)
+	for (auto it = _graphs.cbegin(), end = _graphs.cend(); it != end; ++it) {
+		for (auto const &g: it.value())
 			g->draw(size);
+	}
 
 	for (auto const &s: _shapes) {
 		if (!s)
@@ -345,15 +343,7 @@ void KsGLWidget::wheelEvent(QWheelEvent * event)
 		 * Use the position of the mouse as a focus point for the
 		 * zoom.
 		 */
-#ifdef QT_VERSION_LESS_5_15
-
-	zoomFocus = event->pos().x() - _bin0Offset();
-
-#else
-
-	zoomFocus = event->position().x() - _bin0Offset();
-
-#endif // QT_VERSION_LESS_5_15
+		zoomFocus = event->position().x() - _bin0Offset();
 	}
 
 	if (event->angleDelta().y() > 0) {
@@ -627,12 +617,12 @@ int KsGLWidget::_getMaxLabelSize()
 		int sd = it.key();
 		for (auto const &pid: it.value()._taskList) {
 			size = _font.char_width *
-			       KsUtils::taskPlotName(sd, pid).count();
+			       KsUtils::taskPlotName(sd, pid).size();
 			max = (size > max) ? size : max;
 		}
 
 		for (auto const &cpu: it.value()._cpuList) {
-			size = _font.char_width * KsUtils::cpuPlotName(cpu).count();
+			size = _font.char_width * KsUtils::cpuPlotName(cpu).size();
 			max = (size > max) ? size : max;
 		}
 	}
@@ -641,12 +631,12 @@ int KsGLWidget::_getMaxLabelSize()
 		for (auto const &p: c) {
 			if (p._type & KSHARK_TASK_DRAW) {
 				size = _font.char_width *
-					KsUtils::taskPlotName(p._streamId, p._id).count();
+					KsUtils::taskPlotName(p._streamId, p._id).size();
 
 				max = (size > max) ? size : max;
 			} else if (p._type & KSHARK_CPU_DRAW) {
 				size = _font.char_width *
-				       KsUtils::cpuPlotName(p._id).count();
+				       KsUtils::cpuPlotName(p._id).size();
 
 				max = (size > max) ? size : max;
 			}
@@ -804,13 +794,8 @@ void KsGLWidget::_makePluginShapes()
 
 KsPlot::Graph *KsGLWidget::_newCPUGraph(int sd, int cpu)
 {
-	QString name;
-	/* The CPU graph needs to know only the colors of the tasks. */
-	KsPlot::Graph *graph = new KsPlot::Graph(_model.histo(),
-						 &_pidColors,
-						 &_pidColors);
-
-	kshark_context *kshark_ctx(nullptr);
+	KsPlot::Graph *graph = nullptr;
+	kshark_context *kshark_ctx = nullptr;
 	kshark_data_stream *stream;
 	kshark_entry_collection *col;
 
@@ -821,6 +806,8 @@ KsPlot::Graph *KsGLWidget::_newCPUGraph(int sd, int cpu)
 	if (!stream)
 		return nullptr;
 
+	/* The CPU graph needs to know only the colors of the tasks. */
+	graph = new KsPlot::Graph(_model.histo(), &_pidColors, &_pidColors);
 	graph->setIdleSuppressed(true, stream->idle_pid);
 	graph->setHeight(KS_GRAPH_HEIGHT);
 	graph->setLabelText(KsUtils::cpuPlotName(cpu).toStdString());
@@ -837,15 +824,8 @@ KsPlot::Graph *KsGLWidget::_newCPUGraph(int sd, int cpu)
 
 KsPlot::Graph *KsGLWidget::_newTaskGraph(int sd, int pid)
 {
-	QString name;
-	/*
-	 * The Task graph needs to know the colors of the tasks and the colors
-	 * of the CPUs.
-	 */
-	KsPlot::Graph *graph = new KsPlot::Graph(_model.histo(),
-						 &_pidColors,
-						 &_cpuColors);
-	kshark_context *kshark_ctx(nullptr);
+	KsPlot::Graph *graph = nullptr;
+	kshark_context *kshark_ctx = nullptr;
 	kshark_entry_collection *col;
 	kshark_data_stream *stream;
 
@@ -856,6 +836,9 @@ KsPlot::Graph *KsGLWidget::_newTaskGraph(int sd, int pid)
 	if (!stream)
 		return nullptr;
 
+	/* The Task graph needs to know the colors of the tasks and the colors
+	 * of the CPUs */
+	graph = new KsPlot::Graph(_model.histo(), &_pidColors, &_cpuColors);
 	graph->setHeight(KS_GRAPH_HEIGHT);
 	graph->setLabelText(KsUtils::taskPlotName(sd, pid).toStdString());
 
@@ -1003,15 +986,15 @@ bool KsGLWidget::_find(int bin, int sd, int cpu, int pid,
 		 * The click is over the CPU graphs. First try the exact
 		 * match.
 		 */
-		if (lamGetEntryByCPU(bin))
+		if (lamGetEntryByCPU(b))
 			return true;
 
 		/* Now look for a match, nearby the position of the click. */
 		for (int i = 1; i < variance; ++i) {
-			if (bin + i <= hSize && lamGetEntryByCPU(bin + i))
+			if (b + i <= hSize && lamGetEntryByCPU(b + i))
 				return true;
 
-			if (bin - i >= 0 && lamGetEntryByCPU(bin - i))
+			if (b - i >= 0 && lamGetEntryByCPU(b - i))
 				return true;
 		}
 
@@ -1024,15 +1007,15 @@ bool KsGLWidget::_find(int bin, int sd, int cpu, int pid,
 		 * The click is over the Task graphs. First try the exact
 		 * match.
 		 */
-		if (lamGetEntryByPid(bin))
+		if (lamGetEntryByPid(b))
 			return true;
 
 		/* Now look for a match, nearby the position of the click. */
 		for (int i = 1; i < variance; ++i) {
-			if ((bin + i <= hSize) && lamGetEntryByPid(bin + i))
+			if ((b + i <= hSize) && lamGetEntryByPid(b + i))
 				return true;
 
-			if ((bin - i >= 0) && lamGetEntryByPid(bin - i))
+			if ((b - i >= 0) && lamGetEntryByPid(b - i))
 				return true;
 		}
 
